@@ -206,6 +206,7 @@ def view(ctx, is_raw):
     if workflow_job.complete_date:
         print_tab('completed', complete_date.strftime('%Y-%m-%d %H:%M:%S'))
     print_tab('duration', str(complete_date - submit_date).split('.')[0])
+    print_tab('context', getattr(workflow_job, 'context', ''))
 
     print_tab('nextflow ID', workflow_job.run_id)
     print_tab(
@@ -275,6 +276,7 @@ def events(ctx, is_raw, event_name, process_name, num):
         print(dumps(events))
         return
 
+    echo("Events for job {}:".format(ctx.obj.job.job_id))
     headers = ['first_event_date', 'last_event_date', 'event', 'process', 'status']
     table = []
     for event in events:
@@ -321,6 +323,7 @@ def params(ctx, is_raw):
     if is_raw:
         echo(dumps(params))
         return
+    echo("Parameters for job {}:".format(ctx.obj.job.job_id))
     for k, v in params.items():
         vv = v
         if isinstance(vv, str) and len(vv) > 100:
@@ -335,7 +338,7 @@ def logs(ctx, log_group, log_filter):
     workflow_job = ctx.obj.job
     if not log_group:
         log_groups = workflow_job.log_groups()
-        echo("The following log groups are available:\n  %s" % ("\n  ".join(log_groups.keys())))
+        echo("The following log groups are available for job %s:\n  %s" % (workflow_job.job_id, "\n  ".join(log_groups.keys())))
         sys.exit(1)
     try:
         logs = workflow_job.logs(log_group, log_filter)
@@ -382,7 +385,7 @@ def processes(ctx, is_raw, process_name, output, limit, is_all, status):
         ),
         bold=True,
     )
-    txt = "Processes by status: {}".format(txt)
+    txt = "Processes by status for job {}: {}".format(workflow_job.job_id, txt)
     echo(txt)
 
     if len(processes) == 0 and not is_all:
@@ -478,7 +481,7 @@ def process_pod(ctx, is_raw):
         echo(dumps(pod))
         return
 
-    echo("Showing pod information from when the process was run...  ")
+    echo("Showing pod information for pod {} in job {} from when the process was run...".format(process["process_id"], ctx.obj.job.job_id))
     keys = [
         'name',
         'namespace',
@@ -502,7 +505,7 @@ def process_node(ctx, is_raw):
     if is_raw:
         echo(dumps(node))
         return
-    echo("Showing node information from when the process was run...  ")
+    echo("Showing node information for pod {} in job {} from when the process was run...".format(process["process_id"], ctx.obj.job.job_id))
     keys = ['name', 'creation_timestamp', 'labels', 'capacity', 'node_info']
     output_pretty_json(node, keys=keys)
 
