@@ -20,6 +20,7 @@ log = get_logger()
 @option('--pipeline', 'pipeline', default=None, help='Filter by pipeline name')
 @option('--page', 'is_page', is_flag=True, help='Page results')
 @option('--running', 'is_running', is_flag=True, help='Only show jobs in pending/running state')
+@option('--context', help='Filter by context')
 @option(
     '--completed',
     'is_completed',
@@ -45,6 +46,7 @@ def jobs(
     pipeline,
     is_page,
     is_running,
+    context,
     is_completed,
     num,
     output,
@@ -64,7 +66,7 @@ def jobs(
         state = "completed"
     try:
         jobs = svc.get_jobs(
-            user_name, status, project=project, pipeline=pipeline, limit=num, state=state
+            user_name, status, project=project, pipeline=pipeline, limit=num, state=state, context=context,
         )
     except ServerError as e:
         abort(str(e))
@@ -83,7 +85,7 @@ def jobs(
         'status',
     ]
     if is_wide:
-        fields.extend(['desc', 'complete_date', 'pod', '#proc'])
+        fields.extend(['desc', 'context', 'complete_date', 'pod', '#proc'])
     jobs_list = []
     for job in jobs:
         job_list = []
